<?php

namespace B2buy\MasterSetting\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use B2buy\MasterSetting\Http\Requests\MasterSettingsRequest;
use B2buy\MasterSetting\Models\MasterSettings;

/**
 * Admin web controller class.
 */
class MasterSettingsWorkflowController extends BaseController
{

    /**
     * Workflow controller function for master_settings.
     *
     * @param Model   $master_settings
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(MasterSettingsRequest $request, MasterSettings $master_settings, $step)
    {

        try {

            $master_settings->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('master_setting::master_settings.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/master_settings/master_settings/' . $master_settings->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/master_settings/master_settings/' . $master_settings->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for master_settings.
     *
     * @param Model   $master_settings
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(MasterSettings $master_settings, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $master_settings->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('master_setting::master_settings.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('master_setting::admin.master_settings.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('master_setting::admin.master_settings.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('master_setting::admin.master_settings.message', $data)->render();

        }

    }
}
