<?php

namespace B2buy\MasterSetting\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\MasterSetting\Models\MasterSettings;

class MasterSettingsPolicy
{

    /**
     * Determine if the given user can view the master_settings.
     *
     * @param UserPolicy $user
     * @param MasterSettings $master_settings
     *
     * @return bool
     */
    public function view(UserPolicy $user, MasterSettings $master_settings)
    {
        if ($user->canDo('master_setting.master_settings.view') && $user->isAdmin()) {
            return true;
        }

        return $master_settings->user_id == user_id() && $master_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can create a master_settings.
     *
     * @param UserPolicy $user
     * @param MasterSettings $master_settings
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('master_setting.master_settings.create');
    }

    /**
     * Determine if the given user can update the given master_settings.
     *
     * @param UserPolicy $user
     * @param MasterSettings $master_settings
     *
     * @return bool
     */
    public function update(UserPolicy $user, MasterSettings $master_settings)
    {
        if ($user->canDo('master_setting.master_settings.edit') && $user->isAdmin()) {
            return true;
        }

        return $master_settings->user_id == user_id() && $master_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given master_settings.
     *
     * @param UserPolicy $user
     * @param MasterSettings $master_settings
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, MasterSettings $master_settings)
    {
        return $master_settings->user_id == user_id() && $master_settings->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given master_settings.
     *
     * @param UserPolicy $user
     * @param MasterSettings $master_settings
     *
     * @return bool
     */
    public function verify(UserPolicy $user, MasterSettings $master_settings)
    {
        if ($user->canDo('master_setting.master_settings.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given master_settings.
     *
     * @param UserPolicy $user
     * @param MasterSettings $master_settings
     *
     * @return bool
     */
    public function approve(UserPolicy $user, MasterSettings $master_settings)
    {
        if ($user->canDo('master_setting.master_settings.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
