<?php

namespace B2buy\MasterSetting\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use B2buy\MasterSetting\Models\MasterSettings;

class MasterSettingsAction
{
    /**
     * Perform the complete action.
     *
     * @param MasterSettings $master_settings
     *
     * @return MasterSettings
     */
    public function complete(MasterSettings $master_settings)
    {
        try {
            $master_settings->status = 'complete';
            return $master_settings->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param MasterSettings $master_settings
     *
     * @return MasterSettings
     */public function verify(MasterSettings $master_settings)
    {
        try {
            $master_settings->status = 'verify';
            return $master_settings->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param MasterSettings $master_settings
     *
     * @return MasterSettings
     */public function approve(MasterSettings $master_settings)
    {
        try {
            $master_settings->status = 'approve';
            return $master_settings->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param MasterSettings $master_settings
     *
     * @return MasterSettings
     */public function publish(MasterSettings $master_settings)
    {
        try {
            $master_settings->status = 'publish';
            return $master_settings->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param MasterSettings $master_settings
     *
     * @return MasterSettings
     */
    public function archive(MasterSettings $master_settings)
    {
        try {
            $master_settings->status = 'archive';
            return $master_settings->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param MasterSettings $master_settings
     *
     * @return MasterSettings
     */
    public function unpublish(MasterSettings $master_settings)
    {
        try {
            $master_settings->status = 'unpublish';
            return $master_settings->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
